nowa_runtime library
Classes
- AnimatedSmoothIndicator
- Unlike SmoothPageIndicator this indicator is self-animated and it only needs to know active index
- AudioPlayerController
- AudioSource
- BasicIndicatorEffect
- Basic implementation of IndicatorEffect that holds some shared properties and behaviors between different effects
- BasicIndicatorPainter
- Basic implementation of IndicatorPainter that holds some shared properties and behaviors between different painters
- ColorTransitionEffect
-
Holds painting configuration to be used by
TransitionPainter - CustomButton
- CustomFunction
- CustomizableEffect
-
Holds painting configuration to be used by
CustomizablePainter - CustomWidget
-
DataBuilder<
T> - DotBorder
- Holds dot-border painting specs
- DotDecoration
- Holds dot painting specs
- ErrorView
- ExpandingDotsEffect
-
Holds painting configuration to be used by
ExpandingDotsPainter - FlexSizedBox
- ImagePicker
- Provides an easy way to pick an image/video from the image library, or to take a picture/video with the camera.
- IndicatorEffect
- An Abstraction for a dot-indicator animation effect
- IndicatorPainter
-
A basic abstract implementation of
customPainterto avoid overriding shouldRepaint in every painter - JumpingDotEffect
-
Holds painting configuration to be used by
JumpingDotPainter - LostData
- The response object of ImagePicker.retrieveLostData.
- LostDataResponse
-
The response object of
ImagePicker.getLostData. - Markdown
- NFlex
- A flex widget that includes spacing
- NotifierBuilder
- Widget that updates whenever the change notifier notifies Use instead of AnimatedBuilder when the notifier can be nullable
- NowaGenerated
- NowaVideoPlayer
- NowaVideoPlayerController
- NowaWebView
- NPlatform
- NSlider
- PickedFile
- A PickedFile is a cross-platform, simplified File abstraction.
- ScaleEffect
-
Holds painting configuration to be used by
ScalePainter - ScrollingDotsEffect
-
Holds painting configuration to be used by
ScrollingDotsPainterorScrollingDotsWithFixedCenterPainter - SlideEffect
-
Holds painting configuration to be used by
SlidePainter - SmoothIndicator
- Draws dot-ish representation of pages by the number of count and animates the active page using offset
- SmoothPageIndicator
- A widget that draws a representation of pages count Inside of a PageView
- SwapEffect
-
Holds painting configuration to be used by
SwapPainter - WormEffect
-
Holds painting configuration to be used by
WormPainter - XFile
- A CrossFile is a cross-platform, simplified File abstraction.
Enums
- CameraDevice
-
Which camera to use when picking images/videos while source is
ImageSource.camera. - DotBorderType
- The variants of dot borders
- FileSourceType
- ImageSource
- Specifies the source where the picked image should come from.
- MediaSourceType
- MediaType
- RetrieveType
- The type of the retrieved data in a LostDataResponse.
- SlideType
- The Slide effect variants
- SwapType
- The swap effect variants
- WormType
- The Worm effect variants
Extensions
Constants
- kEmailValidationRegex → const String
- kPhoneValidationRegex → const String
- kTypeImage → const String
- Denotes that an image is being picked.
- kTypeVideo → const String
- Denotes that a video is being picked.
Functions
-
openUrl(
String url) → void -
showMediaPicker(
{required BuildContext context, MediaSourceType sourceType = MediaSourceType.camera, MediaType mediaType = MediaType.image, bool multiSelection = false, int? imageQuality, int? limit, double? maxWidth, double? maxHeight, CameraDevice preferredCamera = CameraDevice.rear, Duration? maxDuration, Future< XFile> openFakeCamera()?}) → Future<List< XFile> >
Typedefs
- ColorBuilder = Color Function(int index)
-
Signature for a function that returns color
for each
index - OnDotClicked = void Function(int index)
- Signature for a callback function used to report dot tap-events